pyannote.core
=============

| Branch  | Build status                                                                                                                     |
|---------|----------------------------------------------------------------------------------------------------------------------------------|
| master  | [![Build Status](https://travis-ci.org/pyannote/pyannote-core.svg?branch=master)](https://travis-ci.org/pyannote/pyannote-core)  |
| develop | [![Build Status](https://travis-ci.org/pyannote/pyannote-core.svg?branch=develop)](https://travis-ci.org/pyannote/pyannote-core) |

[Notebooks](http://nbviewer.ipython.org/github/pyannote/pyannote-core/blob/master/notebook/index.ipynb)
